1.0.0 API documentation: matrix_double2x4.hpp Source File

| 1.0.0 API documentation

matrix_double2x4.hpp
Go to the documentation of this file.
1
4 #pragma once
5 #include "../detail/type_mat2x4.hpp"
6
7 namespace glm
8 {
11
15 typedef mat<2, 4, double, defaultp> dmat2x4;
16
18 }//namespace glm
glm::dmat2x4
mat< 2, 4, double, defaultp > dmat2x4
2 columns of 4 components matrix of double-precision floating-point numbers.
Definition: matrix_double2x4.hpp:15